@@ -262,7 +262,7 @@ gedit_time_plugin_app_activate (GeditAppActivatable *activatable)
 	priv = GEDIT_TIME_PLUGIN (activatable)->priv;
 
 	priv->menu_ext = gedit_app_activatable_extend_menu (activatable, "tools-section");
-	item = g_menu_item_new (_("In_sert Date and Time..."), "win.time");
+	item = g_menu_item_new (_("In_sert Date and Time…"), "win.time");
 	gedit_menu_extension_append_menu_item (priv->menu_ext, item);
 	g_object_unref (item);
 }
@@ -434,9 +434,9 @@ create_model (GtkWidget       *listview,
 	}
 
 	/* fall back to select the first iter */
-	if (!gtk_tree_selection_get_selected (selection, NULL, NULL))
+	if (!gtk_tree_selection_get_selected (selection, NULL, NULL) &&
+	    gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter))
 	{
-		gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
 		gtk_tree_selection_select_iter (selection, &iter);
 	}
 
